Exports RCDF-formatted data to one or more supported open data formats. The function automatically dispatches to the appropriate writer function based on the formats provided.
Arguments
- data
A named list or RCDF object. Each element should be a table or tibble-like object (typically a
dbplyrordplyrtable).- path
The target directory where output files should be saved.
- formats
A character vector of file formats to export to. Supported formats include:
"csv","tsv","json","parquet","xlsx","dta","sav", and"sqlite".- ...
Additional arguments passed to the respective writer functions.
Examples
if (FALSE) { # \dontrun{
dir <- system.file("extdata", package = "rcdf")
rcdf_path <- file.path(dir, 'mtcars.rcdf')
private_key <- file.path(dir, 'sample-private-key-pw.pem')
rcdf_data <- read_rcdf(path = rcdf_path, decryption_key = private_key, password = '1234')
temp_dir <- tempdir()
write_rcdf_as(data = rcdf_data, path = temp_dir, formats = c("csv", "xlsx"))
unlink(temp_dir, force = TRUE)
} # }