This function writes a dataset to a Parquet file. If an encryption key is provided, the data will be encrypted before writing. Otherwise, the function writes the data as a regular Parquet file without encryption.
Arguments
- data
A data frame or tibble to write to a Parquet file.
- path
The file path where the Parquet file will be written.
- ...
Additional arguments passed to
arrow::write_parquet()if no encryption key is provided.- encryption_key
A list containing
aes_keyandaes_iv. If provided, the data will be encrypted using AES before writing to Parquet.